YAML — Translate Toolkit 2.3.0 documentation

# YAML

New in version 2.0.0.

YAML is a common format for web data interchange.

# Non-Conformance

The following are not yet supported:

- Multiline strings:

      include_newlines: |
                  exactly as you see
                  will appear these three
                  lines of poetry

- Abbreviated lists:

      first-name: [Sun, Mon, Tue, Wed, Thu, Fri, Sat]

- Abbreviated dictionaries:

      martin: {name: Martin D'vloper, job: Developer, skill: Elite}

- Quoted strings:

      foo: "quote, double"
      bar: 'quote, single'

- Escaped quotes:

      foo: "Hello \"World\"."
      bar: 'Hello \'World\'.'

- Avoid escaping quotes:

      spamm: 'avoid escaping "double quote"'
      eggs: "avoid escaping 'single quote'"

- Newlines:

      foo: "Hello \n World."

- Booleans:

      foo: True